Class: Aws::SSMIncidents::Types::AttributeValueList

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure, Aws::Structure::Union
Defined in:
lib/aws-sdk-ssmincidents/types.rb

Overview

Note:

AttributeValueList is a union - when making an API calls you must set exactly one of the members.

Use the AttributeValueList to filter by string or integer values.

Defined Under Namespace

Classes: IntegerValues, StringValues, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#integer_values ⇒ Array<Integer>

The list of integer values that the filter matches.

Returns:

  • (Array<Integer>)


85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/aws-sdk-ssmincidents/types.rb', line 85

class AttributeValueList < Struct.new(
  :integer_values,
  :string_values,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class IntegerValues < AttributeValueList; end
  class StringValues < AttributeValueList; end
  class Unknown < AttributeValueList; end
end

#string_values ⇒ Array<String>

The list of string values that the filter matches.

Returns:

  • (Array<String>)


85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/aws-sdk-ssmincidents/types.rb', line 85

class AttributeValueList < Struct.new(
  :integer_values,
  :string_values,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class IntegerValues < AttributeValueList; end
  class StringValues < AttributeValueList; end
  class Unknown < AttributeValueList; end
end

#unknown ⇒ Object

Returns the value of attribute unknown

Returns:

  • (Object) —

    the current value of unknown



85
86
87
# File 'lib/aws-sdk-ssmincidents/types.rb', line 85

def unknown
  @unknown
end