Class: Aws::SSMIncidents::Types::BatchGetIncidentFindingsError

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssmincidents/types.rb

Overview

Details about an error returned for a BatchGetIncidentFindings operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#code ⇒ String

The code associated with an error that was returned for a BatchGetIncidentFindings operation.

Returns:

  • (String)


140
141
142
143
144
145
146
# File 'lib/aws-sdk-ssmincidents/types.rb', line 140

class BatchGetIncidentFindingsError < Struct.new(
  :code,
  :finding_id,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#finding_id ⇒ String

The ID of a specified finding for which an error was returned for a BatchGetIncidentFindings operation.

Returns:

  • (String)


140
141
142
143
144
145
146
# File 'lib/aws-sdk-ssmincidents/types.rb', line 140

class BatchGetIncidentFindingsError < Struct.new(
  :code,
  :finding_id,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#message ⇒ String

The description for an error that was returned for a BatchGetIncidentFindings operation.

Returns:

  • (String)


140
141
142
143
144
145
146
# File 'lib/aws-sdk-ssmincidents/types.rb', line 140

class BatchGetIncidentFindingsError < Struct.new(
  :code,
  :finding_id,
  :message)
  SENSITIVE = []
  include Aws::Structure
end