Class: Aws::SSMIncidents::Types::ListIncidentFindingsInput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssmincidents/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#incident_record_arn ⇒ String

The Amazon Resource Name (ARN) of the incident for which you want to view associated findings.

Returns:

  • (String)


1393
1394
1395
1396
1397
1398
1399
# File 'lib/aws-sdk-ssmincidents/types.rb', line 1393

class ListIncidentFindingsInput < Struct.new(
  :incident_record_arn,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

The maximum number of findings to retrieve per call.

Returns:

  • (Integer)


1393
1394
1395
1396
1397
1398
1399
# File 'lib/aws-sdk-ssmincidents/types.rb', line 1393

class ListIncidentFindingsInput < Struct.new(
  :incident_record_arn,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

The pagination token for the next set of items to return. (You received this token from a previous call.)

Returns:

  • (String)


1393
1394
1395
1396
1397
1398
1399
# File 'lib/aws-sdk-ssmincidents/types.rb', line 1393

class ListIncidentFindingsInput < Struct.new(
  :incident_record_arn,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end