Class: Aws::SSMIncidents::Types::ListIncidentFindingsOutput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssmincidents/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#findings ⇒ Array<Types::FindingSummary>

A list of findings that represent deployments that might be the potential cause of the incident.

Returns:



1413
1414
1415
1416
1417
1418
# File 'lib/aws-sdk-ssmincidents/types.rb', line 1413

class ListIncidentFindingsOutput < Struct.new(
  :findings,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

The pagination token to use when requesting the next set of items. If there are no additional items to return, the string is null.

Returns:

  • (String)


1413
1414
1415
1416
1417
1418
# File 'lib/aws-sdk-ssmincidents/types.rb', line 1413

class ListIncidentFindingsOutput < Struct.new(
  :findings,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end