Class: Aws::SSMIncidents::Types::ListRelatedItemsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSMIncidents::Types::ListRelatedItemsInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssmincidents/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#incident_record_arn ⇒ String
The Amazon Resource Name (ARN) of the incident record containing the listed related items.
-
#max_results ⇒ Integer
The maximum number of related items per page.
-
#next_token ⇒ String
The pagination token for the next set of items to return.
Instance Attribute Details
#incident_record_arn ⇒ String
The Amazon Resource Name (ARN) of the incident record containing the listed related items.
1497 1498 1499 1500 1501 1502 1503 |
# File 'lib/aws-sdk-ssmincidents/types.rb', line 1497 class ListRelatedItemsInput < Struct.new( :incident_record_arn, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of related items per page.
1497 1498 1499 1500 1501 1502 1503 |
# File 'lib/aws-sdk-ssmincidents/types.rb', line 1497 class ListRelatedItemsInput < Struct.new( :incident_record_arn, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The pagination token for the next set of items to return. (You received this token from a previous call.)
1497 1498 1499 1500 1501 1502 1503 |
# File 'lib/aws-sdk-ssmincidents/types.rb', line 1497 class ListRelatedItemsInput < Struct.new( :incident_record_arn, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |