Class: Aws::SSMIncidents::Types::ListTimelineEventsOutput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssmincidents/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#event_summaries ⇒ Array<Types::EventSummary>

Details about each event that occurred during the incident.

Returns:



1688
1689
1690
1691
1692
1693
# File 'lib/aws-sdk-ssmincidents/types.rb', line 1688

class ListTimelineEventsOutput < Struct.new(
  :event_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

The pagination token to use when requesting the next set of items. If there are no additional items to return, the string is null.

Returns:

  • (String)


1688
1689
1690
1691
1692
1693
# File 'lib/aws-sdk-ssmincidents/types.rb', line 1688

class ListTimelineEventsOutput < Struct.new(
  :event_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end