Class: Aws::SSMIncidents::Types::ReplicationSet

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssmincidents/types.rb

Overview

The set of Amazon Web Services Region that your Incident Manager data will be replicated to and the KMS key used to encrypt the data.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arn ⇒ String

The Amazon Resource Name (ARN) of the replication set.

Returns:

  • (String)


1964
1965
1966
1967
1968
1969
1970
1971
1972
1973
1974
1975
# File 'lib/aws-sdk-ssmincidents/types.rb', line 1964

class ReplicationSet < Struct.new(
  :arn,
  :created_by,
  :created_time,
  :deletion_protected,
  :last_modified_by,
  :last_modified_time,
  :region_map,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#created_by ⇒ String

Details about who created the replication set.

Returns:

  • (String)


1964
1965
1966
1967
1968
1969
1970
1971
1972
1973
1974
1975
# File 'lib/aws-sdk-ssmincidents/types.rb', line 1964

class ReplicationSet < Struct.new(
  :arn,
  :created_by,
  :created_time,
  :deletion_protected,
  :last_modified_by,
  :last_modified_time,
  :region_map,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#created_time ⇒ Time

When the replication set was created.

Returns:

  • (Time)


1964
1965
1966
1967
1968
1969
1970
1971
1972
1973
1974
1975
# File 'lib/aws-sdk-ssmincidents/types.rb', line 1964

class ReplicationSet < Struct.new(
  :arn,
  :created_by,
  :created_time,
  :deletion_protected,
  :last_modified_by,
  :last_modified_time,
  :region_map,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#deletion_protected ⇒ Boolean

Determines if the replication set deletion protection is enabled or not. If deletion protection is enabled, you can't delete the last Amazon Web Services Region in the replication set.

Returns:

  • (Boolean)


1964
1965
1966
1967
1968
1969
1970
1971
1972
1973
1974
1975
# File 'lib/aws-sdk-ssmincidents/types.rb', line 1964

class ReplicationSet < Struct.new(
  :arn,
  :created_by,
  :created_time,
  :deletion_protected,
  :last_modified_by,
  :last_modified_time,
  :region_map,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_by ⇒ String

Who last modified the replication set.

Returns:

  • (String)


1964
1965
1966
1967
1968
1969
1970
1971
1972
1973
1974
1975
# File 'lib/aws-sdk-ssmincidents/types.rb', line 1964

class ReplicationSet < Struct.new(
  :arn,
  :created_by,
  :created_time,
  :deletion_protected,
  :last_modified_by,
  :last_modified_time,
  :region_map,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_time ⇒ Time

When the replication set was last updated.

Returns:

  • (Time)


1964
1965
1966
1967
1968
1969
1970
1971
1972
1973
1974
1975
# File 'lib/aws-sdk-ssmincidents/types.rb', line 1964

class ReplicationSet < Struct.new(
  :arn,
  :created_by,
  :created_time,
  :deletion_protected,
  :last_modified_by,
  :last_modified_time,
  :region_map,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#region_map ⇒ Hash<String,Types::RegionInfo>

The map between each Amazon Web Services Region in your replication set and the KMS key that's used to encrypt the data in that Region.

Returns:



1964
1965
1966
1967
1968
1969
1970
1971
1972
1973
1974
1975
# File 'lib/aws-sdk-ssmincidents/types.rb', line 1964

class ReplicationSet < Struct.new(
  :arn,
  :created_by,
  :created_time,
  :deletion_protected,
  :last_modified_by,
  :last_modified_time,
  :region_map,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

The status of the replication set. If the replication set is still pending, you can't use Incident Manager functionality.

Returns:

  • (String)


1964
1965
1966
1967
1968
1969
1970
1971
1972
1973
1974
1975
# File 'lib/aws-sdk-ssmincidents/types.rb', line 1964

class ReplicationSet < Struct.new(
  :arn,
  :created_by,
  :created_time,
  :deletion_protected,
  :last_modified_by,
  :last_modified_time,
  :region_map,
  :status)
  SENSITIVE = []
  include Aws::Structure
end