Class: Aws::SSMIncidents::Waiters::WaitForReplicationSetDeleted
- Inherits:
-
Object
- Object
- Aws::SSMIncidents::Waiters::WaitForReplicationSetDeleted
- Defined in:
- lib/aws-sdk-ssmincidents/waiters.rb,
sig/waiters.rbs
Overview
Wait for a replication set to be deleted
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ WaitForReplicationSetDeleted
constructor
A new instance of WaitForReplicationSetDeleted.
-
#wait(params = {}) ⇒ Types::GetReplicationSetOutput
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ WaitForReplicationSetDeleted
Returns a new instance of WaitForReplicationSetDeleted.
143 144 |
# File 'lib/aws-sdk-ssmincidents/waiters.rb', line 143
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
180 181 182 |
# File 'lib/aws-sdk-ssmincidents/waiters.rb', line 180 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetReplicationSetOutput
Returns a response object which responds to the following methods:
- #replication_set => Types::ReplicationSet
175 |
# File 'lib/aws-sdk-ssmincidents/waiters.rb', line 175
def wait: (
|