Class: Aws::SSMIncidents::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::SSMIncidents::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-ssmincidents/client.rb
Overview
An API client for SSMIncidents. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::SSMIncidents::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#batch_get_incident_findings(params = {}) ⇒ Types::BatchGetIncidentFindingsOutput
Retrieves details about all specified findings for an incident, including descriptive details about each finding.
-
#create_replication_set(params = {}) ⇒ Types::CreateReplicationSetOutput
A replication set replicates and encrypts your data to the provided Regions with the provided KMS key.
-
#create_response_plan(params = {}) ⇒ Types::CreateResponsePlanOutput
Creates a response plan that automates the initial response to incidents.
-
#create_timeline_event(params = {}) ⇒ Types::CreateTimelineEventOutput
Creates a custom timeline event on the incident details page of an incident record.
-
#delete_incident_record(params = {}) ⇒ Struct
Delete an incident record from Incident Manager.
-
#delete_replication_set(params = {}) ⇒ Struct
Deletes all Regions in your replication set.
-
#delete_resource_policy(params = {}) ⇒ Struct
Deletes the resource policy that Resource Access Manager uses to share your Incident Manager resource.
-
#delete_response_plan(params = {}) ⇒ Struct
Deletes the specified response plan.
-
#delete_timeline_event(params = {}) ⇒ Struct
Deletes a timeline event from an incident.
-
#get_incident_record(params = {}) ⇒ Types::GetIncidentRecordOutput
Returns the details for the specified incident record.
-
#get_replication_set(params = {}) ⇒ Types::GetReplicationSetOutput
Retrieve your Incident Manager replication set.
-
#get_resource_policies(params = {}) ⇒ Types::GetResourcePoliciesOutput
Retrieves the resource policies attached to the specified response plan.
-
#get_response_plan(params = {}) ⇒ Types::GetResponsePlanOutput
Retrieves the details of the specified response plan.
-
#get_timeline_event(params = {}) ⇒ Types::GetTimelineEventOutput
Retrieves a timeline event based on its ID and incident record.
-
#list_incident_findings(params = {}) ⇒ Types::ListIncidentFindingsOutput
Retrieves a list of the IDs of findings, plus their last modified times, that have been identified for a specified incident.
-
#list_incident_records(params = {}) ⇒ Types::ListIncidentRecordsOutput
Lists all incident records in your account.
-
#list_related_items(params = {}) ⇒ Types::ListRelatedItemsOutput
List all related items for an incident record.
-
#list_replication_sets(params = {}) ⇒ Types::ListReplicationSetsOutput
Lists details about the replication set configured in your account.
-
#list_response_plans(params = {}) ⇒ Types::ListResponsePlansOutput
Lists all response plans in your account.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags that are attached to the specified response plan or incident.
-
#list_timeline_events(params = {}) ⇒ Types::ListTimelineEventsOutput
Lists timeline events for the specified incident record.
-
#put_resource_policy(params = {}) ⇒ Types::PutResourcePolicyOutput
Adds a resource policy to the specified response plan.
-
#start_incident(params = {}) ⇒ Types::StartIncidentOutput
Used to start an incident from CloudWatch alarms, EventBridge events, or manually.
-
#tag_resource(params = {}) ⇒ Struct
Adds a tag to a response plan.
-
#untag_resource(params = {}) ⇒ Struct
Removes a tag from a resource.
-
#update_deletion_protection(params = {}) ⇒ Struct
Update deletion protection to either allow or deny deletion of the final Region in a replication set.
-
#update_incident_record(params = {}) ⇒ Struct
Update the details of an incident record.
-
#update_related_items(params = {}) ⇒ Struct
Add or remove related items from the related items tab of an incident record.
-
#update_replication_set(params = {}) ⇒ Struct
Add or delete Regions from your replication set.
-
#update_response_plan(params = {}) ⇒ Struct
Updates the specified response plan.
-
#update_timeline_event(params = {}) ⇒ Struct
Updates a timeline event.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
-
#wait_until(waiter_name, params = {}, options = {}) {|w.waiter| ... } ⇒ Boolean
Polls an API operation until a resource enters a desired state.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-ssmincidents/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2306 2307 2308 |
# File 'lib/aws-sdk-ssmincidents/client.rb', line 2306 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2309 2310 2311 |
# File 'lib/aws-sdk-ssmincidents/client.rb', line 2309 def errors_module Errors end |
Instance Method Details
#batch_get_incident_findings(params = {}) ⇒ Types::BatchGetIncidentFindingsOutput
Retrieves details about all specified findings for an incident, including descriptive details about each finding. A finding represents a recent application environment change made by an CodeDeploy deployment or an CloudFormation stack creation or update that can be investigated as a potential cause of the incident.
524 525 526 527 |
# File 'lib/aws-sdk-ssmincidents/client.rb', line 524 def batch_get_incident_findings(params = {}, = {}) req = build_request(:batch_get_incident_findings, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 2177 2178 2179 2180 |
# File 'lib/aws-sdk-ssmincidents/client.rb', line 2164 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::SSMIncidents') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-ssmincidents' context[:gem_version] = '1.67.0' Seahorse::Client::Request.new(handlers, context) end |
#create_replication_set(params = {}) ⇒ Types::CreateReplicationSetOutput
A replication set replicates and encrypts your data to the provided Regions with the provided KMS key.
572 573 574 575 |
# File 'lib/aws-sdk-ssmincidents/client.rb', line 572 def create_replication_set(params = {}, = {}) req = build_request(:create_replication_set, params) req.send_request() end |
#create_response_plan(params = {}) ⇒ Types::CreateResponsePlanOutput
Creates a response plan that automates the initial response to incidents. A response plan engages contacts, starts chat channel collaboration, and initiates runbooks at the beginning of an incident.
688 689 690 691 |
# File 'lib/aws-sdk-ssmincidents/client.rb', line 688 def create_response_plan(params = {}, = {}) req = build_request(:create_response_plan, params) req.send_request() end |
#create_timeline_event(params = {}) ⇒ Types::CreateTimelineEventOutput
Creates a custom timeline event on the incident details page of an incident record. Incident Manager automatically creates timeline events that mark key moments during an incident. You can create custom timeline events to mark important events that Incident Manager can detect automatically.
763 764 765 766 |
# File 'lib/aws-sdk-ssmincidents/client.rb', line 763 def create_timeline_event(params = {}, = {}) req = build_request(:create_timeline_event, params) req.send_request() end |
#delete_incident_record(params = {}) ⇒ Struct
Delete an incident record from Incident Manager.
786 787 788 789 |
# File 'lib/aws-sdk-ssmincidents/client.rb', line 786 def delete_incident_record(params = {}, = {}) req = build_request(:delete_incident_record, params) req.send_request() end |
#delete_replication_set(params = {}) ⇒ Struct
Deletes all Regions in your replication set. Deleting the replication set deletes all Incident Manager data.
810 811 812 813 |
# File 'lib/aws-sdk-ssmincidents/client.rb', line 810 def delete_replication_set(params = {}, = {}) req = build_request(:delete_replication_set, params) req.send_request() end |
#delete_resource_policy(params = {}) ⇒ Struct
Deletes the resource policy that Resource Access Manager uses to share your Incident Manager resource.
838 839 840 841 |
# File 'lib/aws-sdk-ssmincidents/client.rb', line 838 def delete_resource_policy(params = {}, = {}) req = build_request(:delete_resource_policy, params) req.send_request() end |
#delete_response_plan(params = {}) ⇒ Struct
Deletes the specified response plan. Deleting a response plan stops all linked CloudWatch alarms and EventBridge events from creating an incident with this response plan.
862 863 864 865 |
# File 'lib/aws-sdk-ssmincidents/client.rb', line 862 def delete_response_plan(params = {}, = {}) req = build_request(:delete_response_plan, params) req.send_request() end |
#delete_timeline_event(params = {}) ⇒ Struct
Deletes a timeline event from an incident.
890 891 892 893 |
# File 'lib/aws-sdk-ssmincidents/client.rb', line 890 def delete_timeline_event(params = {}, = {}) req = build_request(:delete_timeline_event, params) req.send_request() end |
#get_incident_record(params = {}) ⇒ Types::GetIncidentRecordOutput
Returns the details for the specified incident record.
937 938 939 940 |
# File 'lib/aws-sdk-ssmincidents/client.rb', line 937 def get_incident_record(params = {}, = {}) req = build_request(:get_incident_record, params) req.send_request() end |
#get_replication_set(params = {}) ⇒ Types::GetReplicationSetOutput
Retrieve your Incident Manager replication set.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* wait_for_replication_set_active
* wait_for_replication_set_deleted
983 984 985 986 |
# File 'lib/aws-sdk-ssmincidents/client.rb', line 983 def get_replication_set(params = {}, = {}) req = build_request(:get_replication_set, params) req.send_request() end |
#get_resource_policies(params = {}) ⇒ Types::GetResourcePoliciesOutput
Retrieves the resource policies attached to the specified response plan.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1030 1031 1032 1033 |
# File 'lib/aws-sdk-ssmincidents/client.rb', line 1030 def get_resource_policies(params = {}, = {}) req = build_request(:get_resource_policies, params) req.send_request() end |
#get_response_plan(params = {}) ⇒ Types::GetResponsePlanOutput
Retrieves the details of the specified response plan.
1093 1094 1095 1096 |
# File 'lib/aws-sdk-ssmincidents/client.rb', line 1093 def get_response_plan(params = {}, = {}) req = build_request(:get_response_plan, params) req.send_request() end |
#get_timeline_event(params = {}) ⇒ Types::GetTimelineEventOutput
Retrieves a timeline event based on its ID and incident record.
1135 1136 1137 1138 |
# File 'lib/aws-sdk-ssmincidents/client.rb', line 1135 def get_timeline_event(params = {}, = {}) req = build_request(:get_timeline_event, params) req.send_request() end |
#list_incident_findings(params = {}) ⇒ Types::ListIncidentFindingsOutput
Retrieves a list of the IDs of findings, plus their last modified times, that have been identified for a specified incident. A finding represents a recent application environment change made by an CloudFormation stack creation or update or an CodeDeploy deployment that can be investigated as a potential cause of the incident.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1183 1184 1185 1186 |
# File 'lib/aws-sdk-ssmincidents/client.rb', line 1183 def list_incident_findings(params = {}, = {}) req = build_request(:list_incident_findings, params) req.send_request() end |
#list_incident_records(params = {}) ⇒ Types::ListIncidentRecordsOutput
Lists all incident records in your account. Use this command to retrieve the Amazon Resource Name (ARN) of the incident record you want to update.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1268 1269 1270 1271 |
# File 'lib/aws-sdk-ssmincidents/client.rb', line 1268 def list_incident_records(params = {}, = {}) req = build_request(:list_incident_records, params) req.send_request() end |
#list_related_items(params = {}) ⇒ Types::ListRelatedItemsOutput
List all related items for an incident record.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1319 1320 1321 1322 |
# File 'lib/aws-sdk-ssmincidents/client.rb', line 1319 def (params = {}, = {}) req = build_request(:list_related_items, params) req.send_request() end |
#list_replication_sets(params = {}) ⇒ Types::ListReplicationSetsOutput
Lists details about the replication set configured in your account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1357 1358 1359 1360 |
# File 'lib/aws-sdk-ssmincidents/client.rb', line 1357 def list_replication_sets(params = {}, = {}) req = build_request(:list_replication_sets, params) req.send_request() end |
#list_response_plans(params = {}) ⇒ Types::ListResponsePlansOutput
Lists all response plans in your account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1397 1398 1399 1400 |
# File 'lib/aws-sdk-ssmincidents/client.rb', line 1397 def list_response_plans(params = {}, = {}) req = build_request(:list_response_plans, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags that are attached to the specified response plan or incident.
1427 1428 1429 1430 |
# File 'lib/aws-sdk-ssmincidents/client.rb', line 1427 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#list_timeline_events(params = {}) ⇒ Types::ListTimelineEventsOutput
Lists timeline events for the specified incident record.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1520 1521 1522 1523 |
# File 'lib/aws-sdk-ssmincidents/client.rb', line 1520 def list_timeline_events(params = {}, = {}) req = build_request(:list_timeline_events, params) req.send_request() end |
#put_resource_policy(params = {}) ⇒ Types::PutResourcePolicyOutput
Adds a resource policy to the specified response plan. The resource policy is used to share the response plan using Resource Access Manager (RAM). For more information about cross-account sharing, see [Cross-Region and cross-account incident management].
1560 1561 1562 1563 |
# File 'lib/aws-sdk-ssmincidents/client.rb', line 1560 def put_resource_policy(params = {}, = {}) req = build_request(:put_resource_policy, params) req.send_request() end |
#start_incident(params = {}) ⇒ Types::StartIncidentOutput
Used to start an incident from CloudWatch alarms, EventBridge events, or manually.
1654 1655 1656 1657 |
# File 'lib/aws-sdk-ssmincidents/client.rb', line 1654 def start_incident(params = {}, = {}) req = build_request(:start_incident, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds a tag to a response plan.
1683 1684 1685 1686 |
# File 'lib/aws-sdk-ssmincidents/client.rb', line 1683 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes a tag from a resource.
1710 1711 1712 1713 |
# File 'lib/aws-sdk-ssmincidents/client.rb', line 1710 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_deletion_protection(params = {}) ⇒ Struct
Update deletion protection to either allow or deny deletion of the final Region in a replication set.
1745 1746 1747 1748 |
# File 'lib/aws-sdk-ssmincidents/client.rb', line 1745 def update_deletion_protection(params = {}, = {}) req = build_request(:update_deletion_protection, params) req.send_request() end |
#update_incident_record(params = {}) ⇒ Struct
Update the details of an incident record. You can use this operation to update an incident record from the defined chat channel. For more information about using actions in chat channels, see [Interacting through chat].
[1]: docs.aws.amazon.com/incident-manager/latest/userguide/chat.html#chat-interact
1834 1835 1836 1837 |
# File 'lib/aws-sdk-ssmincidents/client.rb', line 1834 def update_incident_record(params = {}, = {}) req = build_request(:update_incident_record, params) req.send_request() end |
#update_related_items(params = {}) ⇒ Struct
Add or remove related items from the related items tab of an incident record.
1902 1903 1904 1905 |
# File 'lib/aws-sdk-ssmincidents/client.rb', line 1902 def (params = {}, = {}) req = build_request(:update_related_items, params) req.send_request() end |
#update_replication_set(params = {}) ⇒ Struct
Add or delete Regions from your replication set.
1947 1948 1949 1950 |
# File 'lib/aws-sdk-ssmincidents/client.rb', line 1947 def update_replication_set(params = {}, = {}) req = build_request(:update_replication_set, params) req.send_request() end |
#update_response_plan(params = {}) ⇒ Struct
Updates the specified response plan.
2085 2086 2087 2088 |
# File 'lib/aws-sdk-ssmincidents/client.rb', line 2085 def update_response_plan(params = {}, = {}) req = build_request(:update_response_plan, params) req.send_request() end |
#update_timeline_event(params = {}) ⇒ Struct
Updates a timeline event. You can update events of type ‘Custom Event`.
2155 2156 2157 2158 |
# File 'lib/aws-sdk-ssmincidents/client.rb', line 2155 def update_timeline_event(params = {}, = {}) req = build_request(:update_timeline_event, params) req.send_request() end |
#wait_until(waiter_name, params = {}, options = {}) {|w.waiter| ... } ⇒ Boolean
Polls an API operation until a resource enters a desired state.
## Basic Usage
A waiter will call an API operation until:
-
It is successful
-
It enters a terminal state
-
It makes the maximum number of attempts
In between attempts, the waiter will sleep.
# polls in a loop, sleeping between attempts
client.wait_until(waiter_name, params)
## Configuration
You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. You can pass configuration as the final arguments hash.
# poll for ~25 seconds
client.wait_until(waiter_name, params, {
max_attempts: 5,
delay: 5,
})
## Callbacks
You can be notified before each polling attempt and before each delay. If you throw ‘:success` or `:failure` from these callbacks, it will terminate the waiter.
started_at = Time.now
client.wait_until(waiter_name, params, {
# disable max attempts
max_attempts: nil,
# poll for 1 hour, instead of a number of attempts
before_wait: -> (attempts, response) do
throw :failure if Time.now - started_at > 3600
end
})
## Handling Errors
When a waiter is unsuccessful, it will raise an error. All of the failure errors extend from Waiters::Errors::WaiterFailed.
begin
client.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
# resource did not enter the desired state in time
end
## Valid Waiters
The following table lists the valid waiter names, the operations they call, and the default ‘:delay` and `:max_attempts` values.
| waiter_name | params | :delay | :max_attempts | | ——————————– | —————————- | ——– | ————- | | wait_for_replication_set_active | #get_replication_set | 30 | 5 | | wait_for_replication_set_deleted | #get_replication_set | 30 | 5 |
2271 2272 2273 2274 2275 |
# File 'lib/aws-sdk-ssmincidents/client.rb', line 2271 def wait_until(waiter_name, params = {}, = {}) w = waiter(waiter_name, ) yield(w.waiter) if block_given? # deprecated w.wait(params) end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2279 2280 2281 |
# File 'lib/aws-sdk-ssmincidents/client.rb', line 2279 def waiter_names waiters.keys end |